# TIDE Documentation

This directory is the entry point for user guides, API reference, examples, and developer notes.
TODO: replace placeholders with project-specific content.

## Start Here
- overview.md
- getting-started.md

## Guides
- guides/modeling.md
- guides/sources-receivers.md
- guides/boundaries.md
- guides/storage.md
- guides/callbacks.md
- guides/inversion.md
- guides/performance.md
- guides/validation.md

## Examples
- examples/example_multiscale_filtered.md
- examples/example_multiscale_random_sources.md
- examples/wavefield_animation.md
- examples/benchmark_maxwell.md

## API Reference
- api/index.md
- api/tide.md
- api/callbacks.md
- api/resampling.md
- api/cfl.md
- api/padding.md
- api/validation.md
- api/maxwell.md
- api/wavelets.md
- api/staggered.md
- api/utils.md
- api/storage.md
- api/backend_utils.md
- api/csrc.md

## Developer Docs
- dev/build.md
- dev/cuda.md
- dev/testing.md
- dev/contributing.md
